@@ -93,9 +93,13 @@ neutron_opts = [
         deprecated_group="DEFAULT",
         help='Location of CA certificates file to use for '
              'neutron client requests.'),
+    cfg.StrOpt(
+        'endpoint_type',
+        default='publicURL',
+        help='Endpoint type to be used with neutron client calls.'),
     cfg.StrOpt(
         'region_name',
-        help='Region name for connecting to neutron in admin context')
+        help='Region name for connecting to neutron in admin context.'),
 ]
 
 CONF = cfg.CONF
@@ -145,7 +149,12 @@ class API(object):
                 cfg_group=NEUTRON_GROUP,
                 deprecated_opts_for_v2=v2_deprecated_opts)
 
-        return self.auth_obj.get_client(self, context)
+        return self.auth_obj.get_client(
+            self,
+            context,
+            endpoint_type=CONF[NEUTRON_GROUP].endpoint_type,
+            region_name=CONF[NEUTRON_GROUP].region_name,
+        )
 
     @property
     def admin_project_id(self):
@@ -164,18 +173,26 @@ class API(object):
 
     def create_port(self, tenant_id, network_id, host_id=None, subnet_id=None,
                     fixed_ip=None, device_owner=None, device_id=None,
-                    mac_address=None, security_group_ids=None, dhcp_opts=None,
-                    **kwargs):
+                    mac_address=None, port_security_enabled=True,
+                    security_group_ids=None, dhcp_opts=None, **kwargs):
         try:
             port_req_body = {'port': {}}
             port_req_body['port']['network_id'] = network_id
             port_req_body['port']['admin_state_up'] = True
             port_req_body['port']['tenant_id'] = tenant_id
-            if security_group_ids:
+            if not port_security_enabled:
+                port_req_body['port']['port_security_enabled'] = (
+                    port_security_enabled)
+            elif security_group_ids:
                 port_req_body['port']['security_groups'] = security_group_ids
             if mac_address:
                 port_req_body['port']['mac_address'] = mac_address
-            if self._has_port_binding_extension() and host_id:
+            if host_id:
+                if not self._has_port_binding_extension():
+                    msg = ("host_id (%(host_id)s) specified but neutron "
+                           "doesn't support port binding. Please activate the "
+                           "extension accordingly." % {"host_id": host_id})
+                    raise exception.NetworkException(message=msg)
                 port_req_body['port']['binding:host_id'] = host_id
             if dhcp_opts is not None:
                 port_req_body['port']['extra_dhcp_opts'] = dhcp_opts
@@ -358,3 +375,36 @@ class API(object):
         except neutron_client_exc.NeutronClientException as e:
             raise exception.NetworkException(code=e.status_code,
                                              message=e.message)
+
+    def security_group_list(self, search_opts=None):
+        try:
+            return self.client.list_security_groups(**search_opts)
+        except neutron_client_exc.NeutronClientException as e:
+            raise exception.NetworkException(
+                code=e.status_code, message=e.message)
+
+    def security_group_create(self, name, description=""):
+        try:
+            return self.client.create_security_group(
+                {'security_group': {"name": name, "description": description}})
+        except neutron_client_exc.NeutronClientException as e:
+            raise exception.NetworkException(
+                code=e.status_code, message=e.message)
+
+    def security_group_rule_create(self, parent_group_id,
+                                   ip_protocol=None, from_port=None,
+                                   to_port=None, cidr=None, group_id=None,
+                                   direction="ingress"):
+        request = {"security_group_id": parent_group_id,
+                   "protocol": ip_protocol, "remote_ip_prefix": cidr,
+                   "remote_group_id": group_id, "direction": direction}
+        if ip_protocol != "icmp":
+            request["port_range_min"] = from_port
+            request["port_range_max"] = to_port
+
+        try:
+            return self.client.create_security_group_rule(
+                {"security_group_rule": request})
+        except neutron_client_exc.NeutronClientException as e:
+            raise exception.NetworkException(
+                code=e.status_code, message=e.message)
