@@ -107,6 +107,12 @@ _global_opt_lists = [
     manila.network.neutron.neutron_network_plugin.
     neutron_bind_network_plugin_opts,
     manila.network.neutron.neutron_network_plugin.
+    neutron_binding_profile,
+    manila.network.neutron.neutron_network_plugin.
+    neutron_binding_profile_opts,
+    manila.network.neutron.neutron_network_plugin.
+    neutron_network_plugin_opts,
+    manila.network.neutron.neutron_network_plugin.
     neutron_single_network_plugin_opts,
     manila.network.standalone_network_plugin.standalone_network_plugin_opts,
     manila.quota.quota_opts,
