@@ -25,21 +25,20 @@ import netaddr
 from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import importutils
+from oslo_utils import netutils
 import six
 
 from manila.common import constants as const
 from manila import compute
 from manila import context
 from manila import exception
-from manila.i18n import _
-from manila.i18n import _LW
+from manila.i18n import _, _LW
 from manila.network.linux import ip_lib
 from manila.network.neutron import api as neutron
 from manila import utils
 
 LOG = log.getLogger(__name__)
 NEUTRON_NAME = "neutron"
-NOVA_NAME = "nova"
 
 share_servers_handling_mode_opts = [
     cfg.StrOpt(
@@ -105,8 +104,11 @@ share_servers_handling_mode_opts = [
     cfg.StrOpt(
         "service_instance_network_helper_type",
         default=NEUTRON_NAME,
-        help="Allowed values are %s. " % [NOVA_NAME, NEUTRON_NAME] +
-             "Only used if driver_handles_share_servers=True."),
+        deprecated_for_removal=True,
+        deprecated_reason="This option isn't used any longer because "
+                          "nova networking is no longer supported.",
+        help="Used to select between neutron and nova helpers when "
+             "driver_handles_share_servers=True. Obsolete."),
     cfg.StrOpt(
         "admin_network_id",
         help="ID of neutron network used to communicate with admin network,"
@@ -183,22 +185,12 @@ class ServiceInstanceManager(object):
         return CONF.get(key)
 
     def _get_network_helper(self):
-        network_helper_type = (
-            self.get_config_option(
-                "service_instance_network_helper_type").lower())
-        if network_helper_type == NEUTRON_NAME:
-            return NeutronNetworkHelper(self)
-        elif network_helper_type == NOVA_NAME:
-            return NovaNetworkHelper(self)
-        else:
-            raise exception.ManilaException(
-                _("Wrong value '%(provided)s' for config opt "
-                  "'service_instance_network_helper_type'. "
-                  "Allowed values are %(allowed)s.") % dict(
-                      provided=network_helper_type,
-                      allowed=[NOVA_NAME, NEUTRON_NAME]))
+        # Historically, there were multiple types of network helper,
+        # but currently the only network helper type is Neutron.
+        return NeutronNetworkHelper(self)
 
     def __init__(self, driver_config=None):
+
         super(ServiceInstanceManager, self).__init__()
         self.driver_config = driver_config
 
@@ -257,13 +249,13 @@ class ServiceInstanceManager(object):
             self.admin_context,
             self.get_config_option('service_instance_name_or_id'))
 
-        if netaddr.valid_ipv4(data['service_net_name_or_ip']):
+        if netutils.is_valid_ipv4(data['service_net_name_or_ip']):
             data['private_address'] = [data['service_net_name_or_ip']]
         else:
             data['private_address'] = self._get_addresses_by_network_name(
                 data['service_net_name_or_ip'], data['instance'])
 
-        if netaddr.valid_ipv4(data['tenant_net_name_or_ip']):
+        if netutils.is_valid_ipv4(data['tenant_net_name_or_ip']):
             data['public_address'] = [data['tenant_net_name_or_ip']]
         else:
             data['public_address'] = self._get_addresses_by_network_name(
@@ -285,7 +277,7 @@ class ServiceInstanceManager(object):
         for key in ('private_address', 'public_address'):
             data[key + '_v4'] = None
             for address in data[key]:
-                if netaddr.valid_ipv4(address):
+                if netutils.is_valid_ipv4(address):
                     data[key + '_v4'] = address
                     break
         share_server['ip'] = data['private_address_v4']
@@ -338,20 +330,21 @@ class ServiceInstanceManager(object):
             LOG.warning(_LW("Name for service instance security group is not "
                             "provided. Skipping security group step."))
             return None
-        s_groups = [s for s in self.compute_api.security_group_list(context)
-                    if s.name == name]
+        s_groups = self.network_helper.neutron_api.security_group_list({
+            "name": name,
+        })['security_groups']
+        s_groups = [s for s in s_groups if s['name'] == name]
         if not s_groups:
             # Creating security group
             if not description:
-                description = "This security group is intended "\
-                              "to be used by share service."
+                description = ("This security group is intended "
+                               "to be used by share service.")
             LOG.debug("Creating security group with name '%s'.", name)
-            sg = self.compute_api.security_group_create(
-                context, name, description)
+            sg = self.network_helper.neutron_api.security_group_create(
+                name, description)['security_group']
             for protocol, ports in const.SERVICE_INSTANCE_SECGROUP_DATA:
-                self.compute_api.security_group_rule_create(
-                    context,
-                    parent_group_id=sg.id,
+                self.network_helper.neutron_api.security_group_rule_create(
+                    parent_group_id=sg['id'],
                     ip_protocol=protocol,
                     from_port=ports[0],
                     to_port=ports[1],
@@ -558,32 +551,20 @@ class ServiceInstanceManager(object):
 
             security_group = self._get_or_create_security_group(context)
             if security_group:
-                if self.network_helper.NAME == NOVA_NAME:
-                    # NOTE(vponomaryov): Nova-network allows to assign
-                    #                    secgroups only by names.
-                    sg_id = security_group.name
-                else:
-                    sg_id = security_group.id
+                sg_id = security_group['id']
                 LOG.debug(
                     "Adding security group '%(sg)s' to server '%(si)s'.",
                     dict(sg=sg_id, si=service_instance["id"]))
                 self.compute_api.add_security_group_to_server(
                     context, service_instance["id"], sg_id)
 
-            if self.network_helper.NAME == NEUTRON_NAME:
-                ip = (network_data.get('service_port',
-                                       network_data.get(
-                                           'admin_port'))['fixed_ips'])
-                service_instance['ip'] = ip[0]['ip_address']
-                public_ip = (network_data.get(
-                    'public_port', network_data.get(
-                        'service_port'))['fixed_ips'])
-                service_instance['public_address'] = public_ip[0]['ip_address']
-            else:
-                net_name = self.network_helper.get_network_name(network_info)
-                service_instance['ip'] = self._get_server_ip(
-                    service_instance, net_name)
-                service_instance['public_address'] = service_instance['ip']
+            ip = (network_data.get('service_port',
+                                   network_data.get(
+                                       'admin_port'))['fixed_ips'])
+            service_instance['ip'] = ip[0]['ip_address']
+            public_ip = (network_data.get('public_port', network_data.get(
+                'service_port'))['fixed_ips'])
+            service_instance['public_address'] = public_ip[0]['ip_address']
 
         except Exception as e:
             e.detail_data = {'server_details': fail_safe_data}
@@ -947,6 +928,8 @@ class NeutronNetworkHelper(BaseNetworkhelper):
                 device.route.clear_outdated_routes(subnet['cidr'])
             self._plug_interface_in_host(interface_name, device, port)
 
+    @utils.synchronized("service_instance_plug_interface_in_host",
+                        external=True)
     def _plug_interface_in_host(self, interface_name, device, port):
 
         self.vif_driver.plug(interface_name, port['id'], port['mac_address'])
@@ -965,8 +948,6 @@ class NeutronNetworkHelper(BaseNetworkhelper):
         # here we are checking for garbage devices from removed service port
         self._remove_outdated_interfaces(device)
 
-    @utils.synchronized(
-        "service_instance_remove_outdated_interfaces", external=True)
     def _remove_outdated_interfaces(self, device):
         """Finds and removes unused network device."""
         device_cidr_set = self._get_set_of_device_cidrs(device)
@@ -1011,7 +992,8 @@ class NeutronNetworkHelper(BaseNetworkhelper):
         elif not ports:
             port = self.neutron_api.create_port(
                 self.admin_project_id, network_id, subnet_id=subnet_id,
-                device_id=device_id, device_owner='manila:share', host_id=host)
+                device_id=device_id, device_owner='manila:share', host_id=host,
+                port_security_enabled=False)
         else:
             port = ports[0]
         return port
@@ -1087,50 +1069,3 @@ class NeutronNetworkHelper(BaseNetworkhelper):
         for subnet_id in service_network['subnets']:
             subnets.append(self.neutron_api.get_subnet(subnet_id))
         return subnets
-
-
-class NovaNetworkHelper(BaseNetworkhelper):
-    """Nova network helper for Manila service instances.
-
-    All security-group rules are applied to all interfaces of Nova VM
-    using Nova-network. In that case there is no need to create additional
-    service network. Only one thing should be satisfied - Manila host
-    should have access to all tenant networks.
-    This network helper does not create resources.
-    """
-
-    def __init__(self, service_instance_manager):
-        self.compute_api = service_instance_manager.compute_api
-        self.admin_context = service_instance_manager.admin_context
-
-    @property
-    def NAME(self):
-        return NOVA_NAME
-
-    def setup_network(self, network_info):
-        net = self._get_nova_network(network_info['nova_net_id'])
-        network_info['nics'] = [{'net-id': net['id']}]
-        return network_info
-
-    def get_network_name(self, network_info):
-        """Returns name of network for service instance."""
-        return self._get_nova_network(network_info['nova_net_id'])['label']
-
-    def teardown_network(self, server_details):
-        """Nothing to do. Placeholder."""
-
-    def setup_connectivity_with_service_instances(self):
-        """Nothing to do. Placeholder."""
-
-    def _get_nova_network(self, nova_network_id):
-        """Returns network to be used for service instance.
-
-        :param nova_network_id: string with id of network.
-        :returns: dict -- network data as dict
-        :raises: exception.ManilaException
-        """
-        if not nova_network_id:
-            raise exception.ManilaException(
-                _('Nova network for service instance is not provided.'))
-        net = self.compute_api.network_get(self.admin_context, nova_network_id)
-        return net
