@@ -75,6 +75,8 @@ VLAN = '1001'
 VLAN_PORT = 'e0a-1001'
 IP_ADDRESS = '10.10.10.10'
 NETMASK = '255.255.255.0'
+GATEWAY = '10.10.10.1'
+SUBNET = '10.10.10.0/24'
 NET_ALLOCATION_ID = 'fake_allocation_id'
 LIF_NAME_TEMPLATE = 'os_%(net_allocation_id)s'
 LIF_NAME = LIF_NAME_TEMPLATE % {'net_allocation_id': NET_ALLOCATION_ID}
@@ -96,6 +98,27 @@ NETWORK_INTERFACES = [{
     'home-port': VLAN_PORT
 }]
 
+NETWORK_INTERFACES_MULTIPLE = [
+    {
+        'interface_name': 'fake_interface',
+        'address': IP_ADDRESS,
+        'vserver': VSERVER_NAME,
+        'netmask': NETMASK,
+        'role': 'data',
+        'home-node': NODE_NAME,
+        'home-port': VLAN_PORT,
+    },
+    {
+        'interface_name': 'fake_interface_2',
+        'address': '10.10.12.10',
+        'vserver': VSERVER_NAME,
+        'netmask': NETMASK,
+        'role': 'data',
+        'home-node': NODE_NAME,
+        'home-port': PORT,
+    }
+]
+
 IPSPACES = [{
     'uuid': 'fake_uuid',
     'ipspace': IPSPACE_NAME,
@@ -2292,6 +2315,23 @@ PERF_OBJECT_INSTANCE_LIST_INFO_RESPONSE = etree.XML("""
     </instances>
   </results>""")
 
+NET_ROUTES_CREATE_RESPONSE = etree.XML("""
+  <results status="passed">
+    <result>
+      <net-vs-routes-info>
+        <address-family>ipv4</address-family>
+        <destination>%(subnet)s</destination>
+        <gateway>%(gateway)s</gateway>
+        <metric>20</metric>
+        <vserver>%(vserver)s</vserver>
+      </net-vs-routes-info>
+    </result>
+  </results>""" % {
+    'gateway': GATEWAY,
+    'vserver': VSERVER_NAME,
+    'subnet': SUBNET,
+})
+
 FAKE_VOL_XML = """<volume-info xmlns='http://www.netapp.com/filer/admin'>
     <name>open123</name>
     <state>online</state>
