@@ -65,28 +65,7 @@ def get_fake_snap_dict():
         'deleted': '0',
         'created_at': '2015-08-10 00:05:58',
         'updated_at': '2015-08-10 00:05:58',
-        'consistency_group_id': '4b04fdc3-00b9-4909-ba1a-06e9b3f88b67',
-        'cgsnapshot_members': [
-            {
-                'status': 'available',
-                'share_type_id': '1a9ed31e-ee70-483d-93ba-89690e028d7f',
-                'share_id': 'e14b5174-e534-4f35-bc4f-fe81c1575d6f',
-                'user_id': 'a0314a441ca842019b0952224aa39192',
-                'deleted': 'False',
-                'created_at': '2015-08-10 00:05:58',
-                'share': {
-                    'id': '03e2f06e-14f2-45a5-9631-0949d1937bd8',
-                    'deleted': False,
-                },
-                'updated_at': '2015-08-10 00:05:58',
-                'share_proto': 'NFS',
-                'project_id': '13c0be6290934bd98596cfa004650049',
-                'cgsnapshot_id': 'f6aa3b59-57eb-421e-965c-4e182538e36a',
-                'deleted_at': None,
-                'id': '03e2f06e-14f2-45a5-9631-0949d1937bd8',
-                'size': 1,
-            },
-        ],
+        'consistency_group_id': None,
         'deleted_at': None,
         'id': 'f6aa3b59-57eb-421e-965c-4e182538e36a',
         'name': None,
@@ -94,58 +73,6 @@ def get_fake_snap_dict():
     return snap_dict
 
 
-def get_fake_cg_dict():
-    cg_dict = {
-        'status': 'creating',
-        'project_id': '13c0be6290934bd98596cfa004650049',
-        'user_id': 'a0314a441ca842019b0952224aa39192',
-        'description': None,
-        'deleted': 'False',
-        'created_at': '2015-08-10 00:07:58',
-        'updated_at': None,
-        'source_cgsnapshot_id': 'f6aa3b59-57eb-421e-965c-4e182538e36a',
-        'host': 'openstack2@cmodeSSVMNFS',
-        'deleted_at': None,
-        'shares': [
-            {
-                'id': '02a32f06e-14f2-45a5-9631-7483f1937bd8',
-                'deleted': False,
-                'source_cgsnapshot_member_id':
-                    '03e2f06e-14f2-45a5-9631-0949d1937bd8',
-            },
-
-        ],
-        'share_types': [
-            {
-                'id': 'f6aa3b56-45a5-9631-02a32f06e1937b',
-                'deleted': False,
-                'consistency_group_id': '4b04fdc3-00b9-4909-ba1a-06e9b3f88b67',
-                'share_type_id': '1a9ed31e-ee70-483d-93ba-89690e028d7f',
-            },
-        ],
-        'id': 'eda52174-0442-476d-9694-a58327466c14',
-        'name': None
-    }
-    return cg_dict
-
-
-def get_fake_collated_cg_snap_info():
-    fake_collated_cg_snap_info = [
-        {
-            'share': {
-                'id': '02a32f06e-14f2-45a5-9631-7483f1937bd8',
-                'deleted': False,
-                'source_cgsnapshot_member_id':
-                    '03e2f06e-14f2-45a5-9631-0949d1937bd8',
-            },
-            'snapshot': {
-                'id': '03e2f06e-14f2-45a5-9631-0949d1937bd8',
-            },
-        },
-    ]
-    return fake_collated_cg_snap_info
-
-
 def get_fake_access_rule(access_to, access_level, access_type='ip'):
     return {
         'access_type': access_type,
@@ -218,6 +145,7 @@ class GenericShareDriverTestCase(test.TestCase):
             'pk_path': 'fake_pk_path',
             'backend_details': {
                 'ip': '1.2.3.4',
+                'public_address': 'fake_public_address',
                 'instance_id': 'fake',
                 'service_ip': 'fake_ip',
             },
@@ -316,25 +244,19 @@ class GenericShareDriverTestCase(test.TestCase):
     def test_create_share(self):
         volume = 'fake_volume'
         volume2 = 'fake_volume2'
-        self._helper_nfs.create_export.return_value = 'fakelocation'
         self.mock_object(self._driver, '_allocate_container',
                          mock.Mock(return_value=volume))
         self.mock_object(self._driver, '_attach_volume',
                          mock.Mock(return_value=volume2))
         self.mock_object(self._driver, '_format_device')
         self.mock_object(self._driver, '_mount_device')
-        expected_el = [{
-            'is_admin_only': False,
-            'path': 'fakelocation',
-            'metadata': {'export_location_metadata_example': 'example'},
-        }]
 
         result = self._driver.create_share(
             self._context, self.share, share_server=self.server)
 
-        self.assertEqual(expected_el, result)
+        self.assertEqual(self._helper_nfs.create_exports.return_value, result)
         self._driver._allocate_container.assert_called_once_with(
-            self._driver.admin_context, self.share)
+            self._driver.admin_context, self.share, snapshot=None)
         self._driver._attach_volume.assert_called_once_with(
             self._driver.admin_context, self.share,
             self.server['backend_details']['instance_id'],
@@ -385,7 +307,7 @@ class GenericShareDriverTestCase(test.TestCase):
         volume = {'mountpoint': 'fake_mount_point'}
         self.mock_object(self._driver, '_is_device_mounted',
                          mock.Mock(return_value=False))
-        self.mock_object(self._driver, '_sync_mount_temp_and_perm_files')
+        self.mock_object(self._driver, '_add_mount_permanently')
         self.mock_object(self._driver, '_ssh_exec',
                          mock.Mock(return_value=('', '')))
 
@@ -393,13 +315,17 @@ class GenericShareDriverTestCase(test.TestCase):
 
         self._driver._is_device_mounted.assert_called_once_with(
             mount_path, server, volume)
-        self._driver._sync_mount_temp_and_perm_files.assert_called_once_with(
-            server)
+        self._driver._add_mount_permanently.assert_called_once_with(
+            self.share.id, server)
         self._driver._ssh_exec.assert_called_once_with(
-            server,
-            ['sudo mkdir -p', mount_path,
-             '&&', 'sudo mount', volume['mountpoint'], mount_path,
-             '&& sudo chmod 777', mount_path],
+            server, (
+                'sudo', 'mkdir', '-p', mount_path,
+                '&&', 'sudo', 'mount', volume['mountpoint'], mount_path,
+                '&&', 'sudo', 'chmod', '777', mount_path,
+                '&&', 'sudo', 'umount', mount_path,
+                '&&', 'sudo', 'tune2fs', '-U', 'random', volume['mountpoint'],
+                '&&', 'sudo', 'mount', volume['mountpoint'], mount_path,
+            ),
         )
 
     def test_mount_device_present(self):
@@ -439,7 +365,7 @@ class GenericShareDriverTestCase(test.TestCase):
         mount_path = '/fake/mount/path'
         self.mock_object(self._driver, '_is_device_mounted',
                          mock.Mock(return_value=True))
-        self.mock_object(self._driver, '_sync_mount_temp_and_perm_files')
+        self.mock_object(self._driver, '_remove_mount_permanently')
         self.mock_object(self._driver, '_get_mount_path',
                          mock.Mock(return_value=mount_path))
         self.mock_object(self._driver, '_ssh_exec',
@@ -450,11 +376,11 @@ class GenericShareDriverTestCase(test.TestCase):
         self._driver._get_mount_path.assert_called_once_with(self.share)
         self._driver._is_device_mounted.assert_called_once_with(
             mount_path, self.server)
-        self._driver._sync_mount_temp_and_perm_files.assert_called_once_with(
-            self.server)
+        self._driver._remove_mount_permanently.assert_called_once_with(
+            self.share.id, self.server)
         self._driver._ssh_exec.assert_called_once_with(
             self.server,
-            ['sudo umount', mount_path, '&& sudo rmdir', mount_path],
+            ['sudo', 'umount', mount_path, '&&', 'sudo', 'rmdir', mount_path],
         )
 
     def test_unmount_device_retry_once(self):
@@ -468,7 +394,7 @@ class GenericShareDriverTestCase(test.TestCase):
         mount_path = '/fake/mount/path'
         self.mock_object(self._driver, '_is_device_mounted',
                          mock.Mock(return_value=True))
-        self.mock_object(self._driver, '_sync_mount_temp_and_perm_files')
+        self.mock_object(self._driver, '_remove_mount_permanently')
         self.mock_object(self._driver, '_get_mount_path',
                          mock.Mock(return_value=mount_path))
         self.mock_object(self._driver, '_ssh_exec',
@@ -482,11 +408,11 @@ class GenericShareDriverTestCase(test.TestCase):
         self.assertEqual([mock.call(mount_path,
                                     self.server) for i in moves.range(2)],
                          self._driver._is_device_mounted.mock_calls)
-        self._driver._sync_mount_temp_and_perm_files.assert_called_once_with(
-            self.server)
+        self._driver._remove_mount_permanently.assert_called_once_with(
+            self.share.id, self.server)
         self.assertEqual(
-            [mock.call(self.server, ['sudo umount', mount_path,
-                                     '&& sudo rmdir', mount_path])
+            [mock.call(self.server, ['sudo', 'umount', mount_path,
+                                     '&&', 'sudo', 'rmdir', mount_path])
              for i in moves.range(2)],
             self._driver._ssh_exec.mock_calls,
         )
@@ -562,45 +488,57 @@ class GenericShareDriverTestCase(test.TestCase):
             self.server, ['sudo', 'mount'])
         self.assertFalse(result)
 
-    def test_sync_mount_temp_and_perm_files(self):
+    def test_add_mount_permanently(self):
         self.mock_object(self._driver, '_ssh_exec')
-        self._driver._sync_mount_temp_and_perm_files(self.server)
+        self._driver._add_mount_permanently(self.share.id, self.server)
         self._driver._ssh_exec.has_calls(
             mock.call(
                 self.server,
-                ['sudo', 'cp', const.MOUNT_FILE_TEMP, const.MOUNT_FILE]),
-            mock.call(self.server, ['sudo', 'mount', '-a']))
+                ['grep', self.share.id, const.MOUNT_FILE_TEMP,
+                 '|', 'sudo', 'tee', '-a', const.MOUNT_FILE]),
+            mock.call(self.server, ['sudo', 'mount', '-a'])
+        )
 
-    def test_sync_mount_temp_and_perm_files_raise_error_on_copy(self):
+    def test_add_mount_permanently_raise_error_on_add(self):
         self.mock_object(
             self._driver, '_ssh_exec',
             mock.Mock(side_effect=exception.ProcessExecutionError))
         self.assertRaises(
             exception.ShareBackendException,
-            self._driver._sync_mount_temp_and_perm_files,
+            self._driver._add_mount_permanently,
+            self.share.id,
             self.server
         )
         self._driver._ssh_exec.assert_called_once_with(
             self.server,
-            ['sudo', 'cp', const.MOUNT_FILE_TEMP, const.MOUNT_FILE])
+            ['grep', self.share.id, const.MOUNT_FILE_TEMP,
+             '|', 'sudo', 'tee', '-a', const.MOUNT_FILE],
+        )
 
-    def test_sync_mount_temp_and_perm_files_raise_error_on_mount(self):
-        def raise_error_on_mount(*args, **kwargs):
-            if args[1][1] == 'cp':
-                raise exception.ProcessExecutionError()
+    def test_remove_mount_permanently(self):
+        self.mock_object(self._driver, '_ssh_exec')
+        self._driver._remove_mount_permanently(self.share.id, self.server)
+        self._driver._ssh_exec.assert_called_once_with(
+            self.server,
+            ['sudo', 'sed', '-i', '\'/%s/d\'' % self.share.id,
+             const.MOUNT_FILE],
+        )
 
-        self.mock_object(self._driver, '_ssh_exec',
-                         mock.Mock(side_effect=raise_error_on_mount))
+    def test_remove_mount_permanently_raise_error_on_remove(self):
+        self.mock_object(
+            self._driver, '_ssh_exec',
+            mock.Mock(side_effect=exception.ProcessExecutionError))
         self.assertRaises(
             exception.ShareBackendException,
-            self._driver._sync_mount_temp_and_perm_files,
+            self._driver._remove_mount_permanently,
+            self.share.id,
             self.server
         )
-        self._driver._ssh_exec.has_calls(
-            mock.call(
-                self.server,
-                ['sudo', 'cp', const.MOUNT_FILE_TEMP, const.MOUNT_FILE]),
-            mock.call(self.server, ['sudo', 'mount', '-a']))
+        self._driver._ssh_exec.assert_called_once_with(
+            self.server,
+            ['sudo', 'sed', '-i', '\'/%s/d\'' % self.share.id,
+             const.MOUNT_FILE],
+        )
 
     def test_get_mount_path(self):
         result = self._driver._get_mount_path(self.share)
@@ -975,12 +913,6 @@ class GenericShareDriverTestCase(test.TestCase):
     def test_create_share_from_snapshot(self):
         vol1 = 'fake_vol1'
         vol2 = 'fake_vol2'
-        self._helper_nfs.create_export.return_value = 'fakelocation'
-        expected_el = [{
-            'is_admin_only': False,
-            'path': 'fakelocation',
-            'metadata': {'export_location_metadata_example': 'example'},
-        }]
         self.mock_object(self._driver, '_allocate_container',
                          mock.Mock(return_value=vol1))
         self.mock_object(self._driver, '_attach_volume',
@@ -993,15 +925,15 @@ class GenericShareDriverTestCase(test.TestCase):
             self.snapshot,
             share_server=self.server)
 
-        self.assertEqual(expected_el, result)
+        self.assertEqual(self._helper_nfs.create_exports.return_value, result)
         self._driver._allocate_container.assert_called_once_with(
-            self._driver.admin_context, self.share, self.snapshot)
+            self._driver.admin_context, self.share, snapshot=self.snapshot)
         self._driver._attach_volume.assert_called_once_with(
             self._driver.admin_context, self.share,
             self.server['backend_details']['instance_id'], vol1)
         self._driver._mount_device.assert_called_once_with(
             self.share, self.server['backend_details'], vol2)
-        self._helper_nfs.create_export.assert_called_once_with(
+        self._helper_nfs.create_exports.assert_called_once_with(
             self.server['backend_details'], self.share['name'])
 
     def test_create_share_from_snapshot_invalid_helper(self):
@@ -1040,7 +972,7 @@ class GenericShareDriverTestCase(test.TestCase):
         self._driver.delete_share(
             self._context, self.share, share_server=self.server)
 
-        self._helper_nfs.remove_export.assert_called_once_with(
+        self._helper_nfs.remove_exports.assert_called_once_with(
             self.server['backend_details'], self.share['name'])
         self._driver._unmount_device.assert_called_once_with(
             self.share, self.server['backend_details'])
@@ -1199,7 +1131,7 @@ class GenericShareDriverTestCase(test.TestCase):
             self.server['backend_details']['instance_id'], vol1)
         self._driver._mount_device.assert_called_once_with(
             self.share, self.server['backend_details'], vol2)
-        self._helper_nfs.create_export.assert_called_once_with(
+        self._helper_nfs.create_exports.assert_called_once_with(
             self.server['backend_details'], self.share['name'], recreate=True)
 
     def test_ensure_share_volume_is_absent(self):
@@ -1366,6 +1298,24 @@ class GenericShareDriverTestCase(test.TestCase):
         )
         self.assertEqual(ssh_output, result)
 
+    def test__ssh_exec_check_list_comprehensions_still_work(self):
+        ssh_output = 'fake_ssh_output'
+        cmd = ['fake', 'command spaced']
+        ssh = mock.Mock()
+        ssh_pool = mock.Mock()
+        ssh_pool.create = mock.Mock(side_effect=lambda: ssh)
+        ssh_pool.remove = mock.Mock()
+        self.mock_object(processutils, 'ssh_execute',
+                         mock.Mock(return_value=ssh_output))
+        self._driver.ssh_connections = {
+            self.server['instance_id']: (ssh_pool, ssh)
+        }
+
+        self._driver._ssh_exec(self.server, cmd)
+
+        processutils.ssh_execute.assert_called_once_with(
+            ssh, 'fake "command spaced"', check_exit_code=True)
+
     def test_get_share_stats_refresh_false(self):
         self._driver._stats = {'fake_key': 'fake_value'}
 
@@ -1612,8 +1562,12 @@ class GenericShareDriverTestCase(test.TestCase):
             "fake", "fake"
         )
 
-    def test_extend_share(self):
-        fake_volume = "fake"
+    @ddt.data(100, 130, 123)
+    def test_extend_share(self, volume_size):
+        fake_volume = {
+            "name": "fake",
+            "size": volume_size,
+        }
         fake_share = {
             'id': 'fake',
             'share_proto': 'NFS',
@@ -1644,14 +1598,21 @@ class GenericShareDriverTestCase(test.TestCase):
             self._driver.service_instance_manager.get_common_server.called)
         self._driver._unmount_device.assert_called_once_with(
             fake_share, srv_details)
-        self._driver._detach_volume.assert_called_once_with(
-            mock.ANY, fake_share, srv_details)
         self._driver._get_volume.assert_called_once_with(
             mock.ANY, fake_share['id'])
-        self._driver._extend_volume.assert_called_once_with(
-            mock.ANY, fake_volume, new_size)
-        self._driver._attach_volume.assert_called_once_with(
-            mock.ANY, fake_share, srv_details['instance_id'], mock.ANY)
+
+        if new_size > volume_size:
+            self._driver._detach_volume.assert_called_once_with(
+                mock.ANY, fake_share, srv_details)
+            self._driver._extend_volume.assert_called_once_with(
+                mock.ANY, fake_volume, new_size)
+            self._driver._attach_volume.assert_called_once_with(
+                mock.ANY, fake_share, srv_details['instance_id'], mock.ANY)
+        else:
+            self.assertFalse(self._driver._detach_volume.called)
+            self.assertFalse(self._driver._extend_volume.called)
+            self.assertFalse(self._driver._attach_volume.called)
+
         self._helper_nfs.disable_access_for_maintenance.\
             assert_called_once_with(srv_details, 'test_share')
         self._helper_nfs.restore_access_after_maintenance.\
@@ -1810,211 +1771,6 @@ class GenericShareDriverTestCase(test.TestCase):
 
         self.assertEqual(result, actual_result)
 
-    @ddt.data({'consistency_group': {'share_server_id': 'fake'},
-               'result': {'id': 'fake'}},
-              {'consistency_group': None, 'result': {'id': 'fake'}},
-              {'consistency_group': {'share_server_id': 'test'},
-               'result': {'id': 'test'}})
-    @ddt.unpack
-    def tests_choose_share_server_compatible_with_share_and_cg(
-            self, consistency_group, result):
-        share_servers = [{'id': 'fake'}, {'id': 'test'}]
-        fake_share = "fake"
-
-        actual_result = self._driver.choose_share_server_compatible_with_share(
-            self._context, share_servers, fake_share,
-            consistency_group=consistency_group
-        )
-
-        self.assertEqual(result, actual_result)
-
-    def test_create_consistency_group(self):
-        FAKE_SNAP_DICT = get_fake_snap_dict()
-
-        result = self._driver.create_consistency_group(
-            self._context, FAKE_SNAP_DICT, share_server=self.server)
-
-        self.assertEqual(1, self.mock_debug_log.call_count)
-        self.assertEqual(1, self.mock_warning_log.call_count)
-        self.assertIsNone(result)
-
-    def test_delete_consistency_group(self):
-        FAKE_SNAP_DICT = get_fake_snap_dict()
-
-        result = self._driver.delete_consistency_group(
-            self._context, FAKE_SNAP_DICT, share_server=self.server)
-
-        self.assertEqual(1, self.mock_debug_log.call_count)
-        self.assertIsNone(result)
-
-    def test_create_cgsnapshot_no_cg_members(self):
-        FAKE_SNAP_DICT = dict(get_fake_snap_dict(), cgsnapshot_members=[])
-        mock_snapshot_creation = self.mock_object(generic.GenericShareDriver,
-                                                  'create_snapshot')
-
-        result = self._driver.create_cgsnapshot(
-            self._context, FAKE_SNAP_DICT, share_server=self.server)
-
-        self.assertEqual(1, self.mock_debug_log.call_count)
-        self.assertEqual(2, self.mock_warning_log.call_count)
-        self.assertFalse(mock_snapshot_creation.called)
-        self.assertEqual((None, None), result)
-
-    @ddt.data(
-        {
-            'delete_snap_side_effect': None,
-            'expected_error_log_call_count': 0,
-        },
-        {
-            'delete_snap_side_effect': exception.ManilaException,
-            'expected_error_log_call_count': 1,
-        }
-    )
-    @ddt.unpack
-    def test_create_cgsnapshot_manila_exception_on_create_and_delete(
-            self, delete_snap_side_effect, expected_error_log_call_count):
-        FAKE_SNAP_DICT = get_fake_snap_dict()
-        # Append another fake share
-        FAKE_SHARE = dict(FAKE_SNAP_DICT['cgsnapshot_members'][0])
-        FAKE_SNAP_DICT['cgsnapshot_members'].append(FAKE_SHARE)
-
-        self.mock_object(generic.GenericShareDriver,
-                         'create_snapshot',
-                         mock.Mock(side_effect=[
-                             None,
-                             exception.ManilaException,
-                         ]))
-        self.mock_object(generic.GenericShareDriver,
-                         'delete_snapshot',
-                         mock.Mock(side_effect=delete_snap_side_effect))
-
-        self.assertRaises(exception.ManilaException,
-                          self._driver.create_cgsnapshot,
-                          self._context, FAKE_SNAP_DICT,
-                          share_server=self.server)
-        self.assertEqual(2, self.mock_debug_log.call_count)
-        self.assertEqual(1, self.mock_warning_log.call_count)
-        self.assertEqual(1, self.mock_exception_log.call_count)
-        self.assertEqual(expected_error_log_call_count,
-                         self.mock_error_log.call_count)
-
-    def test_create_cgsnapshot(self):
-        FAKE_SNAP_DICT = get_fake_snap_dict()
-        FAKE_SHARE_SNAPSHOT = {
-            'share_id': 'e14b5174-e534-4f35-bc4f-fe81c1575d6f',
-            'id': '03e2f06e-14f2-45a5-9631-0949d1937bd8',
-        }
-
-        mock_snapshot_creation = self.mock_object(generic.GenericShareDriver,
-                                                  'create_snapshot')
-
-        result = self._driver.create_cgsnapshot(
-            self._context, FAKE_SNAP_DICT, share_server=self.server)
-
-        mock_snapshot_creation.assert_called_once_with(self._context,
-                                                       FAKE_SHARE_SNAPSHOT,
-                                                       self.server)
-
-        self.assertEqual(2, self.mock_debug_log.call_count)
-        self.assertEqual(1, self.mock_warning_log.call_count)
-        self.assertFalse(self.mock_error_log.called)
-        self.assertEqual((None, None), result)
-
-    def test_delete_cgsnapshot_manila_exception(self):
-        FAKE_SNAP_DICT = get_fake_snap_dict()
-        self.mock_object(generic.GenericShareDriver,
-                         'delete_snapshot',
-                         mock.Mock(side_effect=exception.ManilaException))
-
-        self.assertRaises(exception.ManilaException,
-                          self._driver.delete_cgsnapshot,
-                          self._context, FAKE_SNAP_DICT,
-                          share_server=self.server)
-
-        self.assertEqual(1, self.mock_error_log.call_count)
-
-    def test_delete_cgsnapshot(self):
-        FAKE_SNAP_DICT = get_fake_snap_dict()
-        FAKE_SHARE_SNAPSHOT = {
-            'share_id': 'e14b5174-e534-4f35-bc4f-fe81c1575d6f',
-            'id': '03e2f06e-14f2-45a5-9631-0949d1937bd8',
-        }
-        mock_snapshot_creation = self.mock_object(generic.GenericShareDriver,
-                                                  'delete_snapshot')
-
-        result = self._driver.delete_cgsnapshot(
-            self._context, FAKE_SNAP_DICT, share_server=self.server)
-
-        mock_snapshot_creation.assert_called_once_with(self._context,
-                                                       FAKE_SHARE_SNAPSHOT,
-                                                       self.server)
-
-        self.assertEqual(2, self.mock_debug_log.call_count)
-        self.assertEqual((None, None), result)
-
-    def test_create_consistency_group_from_cgsnapshot_no_members(self):
-        FAKE_CG_DICT = get_fake_cg_dict()
-        FAKE_CGSNAP_DICT = dict(get_fake_snap_dict(), cgsnapshot_members=[])
-        mock_share_creation = self.mock_object(generic.GenericShareDriver,
-                                               'create_share_from_snapshot')
-
-        result = self._driver.create_consistency_group_from_cgsnapshot(
-            self._context, FAKE_CG_DICT, FAKE_CGSNAP_DICT,
-            share_server=self.server)
-
-        self.assertFalse(self.mock_debug_log.called)
-        self.assertFalse(mock_share_creation.called)
-        self.assertEqual((None, None), result)
-
-    def test_create_consistency_group_from_cgsnapshot(self):
-        FAKE_CG_DICT = get_fake_cg_dict()
-        FAKE_CGSNAP_DICT = get_fake_snap_dict()
-        FAKE_COLLATED_INFO = get_fake_collated_cg_snap_info()
-        FAKE_SHARE_UPDATE_LIST = [
-            {
-                'id': '02a32f06e-14f2-45a5-9631-7483f1937bd8',
-                'export_locations': 'xyzzy',
-            }
-        ]
-        self.mock_object(generic.GenericShareDriver,
-                         '_collate_cg_snapshot_info',
-                         mock.Mock(return_value=FAKE_COLLATED_INFO))
-        mock_share_creation = self.mock_object(generic.GenericShareDriver,
-                                               'create_share_from_snapshot',
-                                               mock.Mock(return_value='xyzzy'))
-
-        result = self._driver.create_consistency_group_from_cgsnapshot(
-            self._context, FAKE_CG_DICT, FAKE_CGSNAP_DICT,
-            share_server=self.server)
-
-        self.assertEqual((None, FAKE_SHARE_UPDATE_LIST), result)
-        self.assertEqual(1, self.mock_debug_log.call_count)
-        mock_share_creation.assert_called_once_with(
-            self._context,
-            FAKE_COLLATED_INFO[0]['share'],
-            FAKE_COLLATED_INFO[0]['snapshot'],
-            share_server=self.server
-        )
-
-    def test_collate_cg_snapshot_info_invalid_cg(self):
-        FAKE_CG_DICT = get_fake_cg_dict()
-        FAKE_CGSNAP_DICT = dict(get_fake_snap_dict(), cgsnapshot_members=[])
-
-        self.assertRaises(exception.InvalidConsistencyGroup,
-                          self._driver._collate_cg_snapshot_info,
-                          FAKE_CG_DICT,
-                          FAKE_CGSNAP_DICT)
-
-    def test_collate_cg_snapshot(self):
-        FAKE_CG_DICT = get_fake_cg_dict()
-        FAKE_CGSNAP_DICT = get_fake_snap_dict()
-        FAKE_COLLATED_INFO = get_fake_collated_cg_snap_info()
-
-        result = self._driver._collate_cg_snapshot_info(
-            FAKE_CG_DICT, FAKE_CGSNAP_DICT)
-
-        self.assertEqual(FAKE_COLLATED_INFO, result)
-
     def test_manage_snapshot_not_found(self):
         snapshot_instance = {'id': 'snap_instance_id',
                              'provider_location': 'vol_snap_id'}
