@@ -114,19 +114,25 @@ class GenericUtilsTestCase(test.TestCase):
     @ddt.data(
         (("3G", "G"), 3.0),
         (("4.1G", "G"), 4.1),
+        (("4,1G", "G"), 4.1),
         (("5.23G", "G"), 5.23),
+        (("5,23G", "G"), 5.23),
         (("9728M", "G"), 9.5),
         (("8192K", "G"), 0.0078125),
         (("2T", "G"), 2048.0),
         (("2.1T", "G"), 2150.4),
+        (("2,1T", "G"), 2150.4),
         (("3P", "G"), 3145728.0),
         (("3.4P", "G"), 3565158.4),
+        (("3,4P", "G"), 3565158.4),
         (("9728M", "M"), 9728.0),
         (("9728.2381T", "T"), 9728.2381),
+        (("9728,2381T", "T"), 9728.2381),
         (("0", "G"), 0.0),
         (("512", "M"), 0.00048828125),
         (("2097152.", "M"), 2.0),
         ((".1024", "K"), 0.0001),
+        ((",1024", "K"), 0.0001),
         (("2048G", "T"), 2.0),
         (("65536G", "P"), 0.0625),
     )
@@ -143,6 +149,14 @@ class GenericUtilsTestCase(test.TestCase):
         ("1KM", "G"),
         ("K1M", "G"),
         ("M1K", "G"),
+        ("1.2fake", "G"),
+        ("1,2fake", "G"),
+        ("2.2GG", "G"),
+        ("1.1KM", "G"),
+        ("K2.2M", "G"),
+        ("K2,2M", "G"),
+        ("M2.2K", "G"),
+        ("M2,2K", "G"),
         ("", "G"),
         (23, "G"),
         (23.0, "G"),
