@@ -18,7 +18,6 @@
 """Utilities and helper functions."""
 
 import contextlib
-import errno
 import functools
 import inspect
 import os
@@ -38,10 +37,13 @@ from oslo_concurrency import processutils
 from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import importutils
+from oslo_utils import netutils
+from oslo_utils import strutils
 from oslo_utils import timeutils
 import paramiko
 import retrying
 import six
+from webob import exc
 
 from manila.common import constants
 from manila.db import api as db_api
@@ -218,87 +220,6 @@ class LazyPluggable(object):
         return getattr(backend, key)
 
 
-def delete_if_exists(pathname):
-    """Delete a file, but ignore file not found error."""
-
-    try:
-        os.unlink(pathname)
-    except OSError as e:
-        if e.errno == errno.ENOENT:
-            return
-        else:
-            raise
-
-
-def get_from_path(items, path):
-    """Returns a list of items matching the specified path.
-
-    Takes an XPath-like expression e.g. prop1/prop2/prop3, and for each item
-    in items, looks up items[prop1][prop2][prop3].  Like XPath, if any of the
-    intermediate results are lists it will treat each list item individually.
-    A 'None' in items or any child expressions will be ignored, this function
-    will not throw because of None (anywhere) in items.  The returned list
-    will contain no None values.
-
-    """
-    if path is None:
-        raise exception.Error('Invalid mini_xpath')
-
-    (first_token, sep, remainder) = path.partition('/')
-
-    if first_token == '':
-        raise exception.Error('Invalid mini_xpath')
-
-    results = []
-
-    if items is None:
-        return results
-
-    if not isinstance(items, list):
-        # Wrap single objects in a list
-        items = [items]
-
-    for item in items:
-        if item is None:
-            continue
-        get_method = getattr(item, 'get', None)
-        if get_method is None:
-            continue
-        child = get_method(first_token)
-        if child is None:
-            continue
-        if isinstance(child, list):
-            # Flatten intermediate lists
-            for x in child:
-                results.append(x)
-        else:
-            results.append(child)
-
-    if not sep:
-        # No more tokens
-        return results
-    else:
-        return get_from_path(results, remainder)
-
-
-def is_ipv6_configured():
-    """Check if system contain IPv6 capable network interface.
-
-    :rtype: bool
-    :raises: IOError
-    """
-    try:
-        fd = open('/proc/net/if_inet6')
-    except IOError as e:
-        if e.errno != errno.ENOENT:
-            raise
-        result = False
-    else:
-        result = bool(fd.read(32))
-        fd.close()
-    return result
-
-
 def is_eventlet_bug105():
     """Check if eventlet support IPv6 addresses.
 
@@ -371,26 +292,6 @@ def monkey_patch():
                         decorator("%s.%s" % (module, key), func))
 
 
-def read_cached_file(filename, cache_info, reload_func=None):
-    """Read from a file if it has been modified.
-
-    :param cache_info: dictionary to hold opaque cache.
-    :param reload_func: optional function to be called with data when
-                        file is reloaded due to a modification.
-
-    :returns: data from file
-
-    """
-    mtime = os.path.getmtime(filename)
-    if not cache_info or mtime != cache_info.get('mtime'):
-        with open(filename) as fap:
-            cache_info['data'] = fap.read()
-        cache_info['mtime'] = mtime
-        if reload_func:
-            reload_func(cache_info['data'])
-    return cache_info['data']
-
-
 def file_open(*args, **kwargs):
     """Open file
 
@@ -421,35 +322,6 @@ def validate_service_host(context, host):
     return service
 
 
-def read_file_as_root(file_path):
-    """Secure helper to read file as root."""
-    try:
-        out, _err = execute('cat', file_path, run_as_root=True)
-        return out
-    except exception.ProcessExecutionError:
-        raise exception.FileNotFound(file_path=file_path)
-
-
-@contextlib.contextmanager
-def temporary_chown(path, owner_uid=None):
-    """Temporarily chown a path.
-
-    :params owner_uid: UID of temporary owner (defaults to current user)
-    """
-    if owner_uid is None:
-        owner_uid = os.getuid()
-
-    orig_uid = os.stat(path).st_uid
-
-    if orig_uid != owner_uid:
-        execute('chown', owner_uid, path, run_as_root=True)
-    try:
-        yield
-    finally:
-        if orig_uid != owner_uid:
-            execute('chown', orig_uid, path, run_as_root=True)
-
-
 @contextlib.contextmanager
 def tempdir(**kwargs):
     tmpdir = tempfile.mkdtemp(**kwargs)
@@ -459,7 +331,7 @@ def tempdir(**kwargs):
         try:
             shutil.rmtree(tmpdir)
         except OSError as e:
-            LOG.debug('Could not remove tmpdir: %s', six.text_type(e))
+            LOG.debug('Could not remove tmpdir: %s', e)
 
 
 def walk_class_hierarchy(clazz, encountered=None):
@@ -475,21 +347,6 @@ def walk_class_hierarchy(clazz, encountered=None):
             yield subclass
 
 
-def ensure_tree(path):
-    """Create a directory (and any ancestor directories required)
-
-    :param path: Directory to create
-    """
-    try:
-        os.makedirs(path)
-    except OSError as exc:
-        if exc.errno == errno.EEXIST:
-            if not os.path.isdir(path):
-                raise
-        else:
-            raise
-
-
 def cidr_to_netmask(cidr):
     """Convert cidr to netmask."""
     try:
@@ -501,9 +358,9 @@ def cidr_to_netmask(cidr):
 
 def is_valid_ip_address(ip_address, ip_version):
     if int(ip_version) == 4:
-        return netaddr.valid_ipv4(ip_address)
+        return netutils.is_valid_ipv4(ip_address)
     elif int(ip_version) == 6:
-        return netaddr.valid_ipv6(ip_address)
+        return netutils.is_valid_ipv6(ip_address)
     else:
         raise exception.ManilaException(
             _("Provided improper IP version '%s'.") % ip_version)
@@ -606,6 +463,52 @@ def retry(exception, interval=1, retries=10, backoff_rate=2,
     return _decorator
 
 
+def get_bool_from_api_params(key, params, default=False, strict=True):
+    """Parse bool value from request params.
+
+    HTTPBadRequest will be directly raised either of the cases below:
+    1. invalid bool string was found by key(with strict on).
+    2. key not found while default value is invalid(with strict on).
+    """
+    param = params.get(key, default)
+    try:
+        param = strutils.bool_from_string(param,
+                                          strict=strict,
+                                          default=default)
+    except ValueError:
+        msg = _('Invalid value %(param)s for %(param_string)s. '
+                'Expecting a boolean.') % {'param': param,
+                                           'param_string': key}
+        raise exc.HTTPBadRequest(explanation=msg)
+    return param
+
+
+def check_params_exist(keys, params):
+    """Validates if keys exist in params.
+
+    :param keys: List of keys to check
+    :param params: Parameters received from REST API
+    """
+    if any(set(keys) - set(params)):
+        msg = _("Must specify all mandatory parameters: %s") % keys
+        raise exc.HTTPBadRequest(explanation=msg)
+
+
+def check_params_are_boolean(keys, params, default=False):
+    """Validates if keys in params are boolean.
+
+    :param keys: List of keys to check
+    :param params: Parameters received from REST API
+    :param default: default value when it does not exist
+    :return: a dictionary with keys and respective retrieved value
+    """
+    result = {}
+    for key in keys:
+        value = get_bool_from_api_params(key, params, default, strict=True)
+        result[key] = value
+    return result
+
+
 def require_driver_initialized(func):
     @functools.wraps(func)
     def wrapper(self, *args, **kwargs):
@@ -647,14 +550,15 @@ def translate_string_size_to_float(string, multiplier='G'):
             }
         )
     try:
-        value = float(string) / 1024.0
+        value = float(string.replace(",", ".")) / 1024.0
         value = value / mapping[multiplier]
         return value
     except (ValueError, TypeError):
         matched = re.match(
-            r"^(\d+\.*\d*)([%s])$" % ','.join(multipliers), string)
+            r"^(\d*[.,]*\d*)([%s])$" % ''.join(multipliers), string)
         if matched:
-            value = float(matched.groups()[0])
+            # The replace() is needed in case decimal separator is a comma
+            value = float(matched.groups()[0].replace(",", "."))
             multiplier = mapping[matched.groups()[1]] / mapping[multiplier]
             return value * multiplier
 
@@ -673,7 +577,8 @@ def wait_for_access_update(context, db, share_instance,
 
         tries += 1
         now = time.time()
-        if instance['access_rules_status'] == constants.STATUS_ERROR:
+        if (instance['access_rules_status'] ==
+                constants.SHARE_INSTANCE_RULES_ERROR):
             msg = _("Failed to update access rules"
                     " on share instance %s") % share_instance['id']
             raise exception.ShareMigrationFailed(reason=msg)
